@@ -138,3 +138,32 @@ class TestValidators(TestCase):
         self.assertRaises(ValidationError, model.validate)
         model.field = datetime.now()
         model.validate()
+
+    def test_choices(self):
+        class Model(BaseModel):
+            field: StringField(required=True, choices=["a", "b", "c"])
+
+        class ModelNotRequired(BaseModel):
+            field: StringField(required=False, choices=["a", "b", "c"])
+
+        model = Model({"field": "a"})
+        model.validate()
+        model.field = "b"
+        model.validate()
+        model.field = "c"
+        model.validate()
+        model.field = "d"
+        self.assertRaises(ValidationError, model.validate)
+        model.field = None
+        self.assertRaises(ValidationError, model.validate)
+
+        model = ModelNotRequired({"field": "a"})
+        model.validate()
+        model.field = "b"
+        model.validate()
+        model.field = "c"
+        model.validate()
+        model.field = "d"
+        self.assertRaises(ValidationError, model.validate)
+        model.field = None
+        model.validate()
