@@ -23,7 +23,8 @@ class BaseModel(MetaModel):
             value = attrs.get(field, self.__def_values__.get(field, None))
             if callable(value):
                 value = value()
-            self.__dict__[field] = value
+            # setting via __dict__ will ignore descriptors
+            setattr(self, field, value)
         self._initial_state = None
         self.__set_initial_state()
         self.__hooks__ = []
@@ -63,7 +64,9 @@ class BaseModel(MetaModel):
         return initial_state
 
     @classmethod
-    def register_model_hook(cls, model_hook_class: Type[BaseModelHook], *args, **kwargs) -> None:
+    def register_model_hook(
+        cls, model_hook_class: Type[BaseModelHook], *args, **kwargs
+    ) -> None:
         if not issubclass(model_hook_class, BaseModelHook):
             raise TypeError("Invalid hook class")
         if cls.__hooks_classes__ is None:
@@ -116,7 +119,7 @@ class BaseModel(MetaModel):
     def invalidate(self, **kwargs) -> None:
         pass
 
-    def destroy(self, skip_callback=False, invalidate_cache=True) -> 'BaseModel':
+    def destroy(self, skip_callback=False, invalidate_cache=True) -> "BaseModel":
         if self.is_new:
             return self
         if not skip_callback:
@@ -142,7 +145,7 @@ class BaseModel(MetaModel):
                     e,
                 )
 
-    def save(self, skip_callback=False, invalidate_cache=True) -> 'BaseModel':
+    def save(self, skip_callback=False, invalidate_cache=True) -> "BaseModel":
         is_new = self.is_new
 
         if not skip_callback:
@@ -218,15 +221,15 @@ class BaseModel(MetaModel):
         return result
 
     @classmethod
-    def create(cls, **attrs) -> 'BaseModel':
+    def create(cls, **attrs) -> "BaseModel":
         return cls(attrs)
 
     @classmethod
-    def _ctor(cls, attrs, **kwargs) -> 'BaseModel':
+    def _ctor(cls, attrs, **kwargs) -> "BaseModel":
         return cls(attrs, **kwargs)
 
     @classmethod
-    def __get_possible_databases(cls) -> List['Shard']:
+    def __get_possible_databases(cls) -> List["Shard"]:
         return [db.meta]
 
     @classmethod
@@ -260,4 +263,6 @@ class BaseModel(MetaModel):
             if field == "_id":
                 continue
             value = getattr(obj, field)
-            self.__dict__[field] = value
+
+            # setting via __dict__ will ignore descriptors
+            setattr(self, field, value)
